Amelia
======

A flexible ircbot written on top of untwisted framework.

Features
========

- **Interface with WollframAlpha**

- **Run python, c, c++, D, haskell, lua, ocalml, PHP, perl, ruby, scheme, tcl code inline or multiline way**

- **Share files with friends on irc**

- **A translator plugin**

- **A real time translator plugin**

- **Quick searches on google**

- **Url tittle extraction**

- **Database with tons of philosophical quotes**

- **Pipe channel messages to other channels**

- **A note system to leave msgs to friends**

- **A last seen plugin**

- **A nifty help system**

- **A neat plugin API**


Install
=======

**Note:**  Amelia demands python3 to work.

~~~
pip install -r requirements.txt
pip install ameliabot
~~~

Documentation
=============

[Wiki](https://github.com/iogf/ameliabot/wiki)







